<?php

namespace App\Request;

use Symfony\Component\HttpFoundation\Request;

/**
 * A Datatables.net request (AJAX)
 */
class DatatableRequest {
    /**
     * @var string|null The searched value, Null if none
     */
    private ?string $search;
    /**
     * @var array{column: string, direction: string}[] The sorts : “column” = column name, “direction” = the sort direction (“asc” / “desc”)
     */
    private array $sorts;
    /**
     * @var int Paging: start position (aka offset)
     */
    private int $pagingStart;
    /**
     * @var int Paging: length (aka number of elements)
     */
    private int $pagingLength;

    /**
     * Initialization from an HTTP request
     *
     * @param Request $request The HTTP request
     */
    public function __construct (Request $request) {
        $this->search = $request->request->all('search')['value'] ?? null;

        //region Sorts
        $this->sorts = [];
        foreach (($request->request->all('order') ?? []) as $orderPosition => $order) {
            $this->sorts[$orderPosition] = [
                'column'    => $order['name'] ?? $order['column'],
                'direction' => $order['dir'] ?? 'asc',
            ];
        }
        //endregion

        $this->pagingStart = $request->request->get('start');
        $this->pagingLength = $request->request->get('length');
    }

    /**
     * The searched value, Null if none
     *
     * @return string|null The searched value, Null if none
     */
    public function getSearch (): ?string {
        return $this->search;
    }

    /**
     * The sorts : “column” = column name, “direction” = the sort direction (“asc” / “desc”)
     *
     * @return array{column: string, direction: string}[] The sorts : “column” = column name, “direction” = the sort direction (“asc” / “desc”)
     */
    public function getSorts (): array {
        return $this->sorts;
    }

    /**
     * Paging: start position (aka offset)
     *
     * @return int Paging: start position (aka offset)
     */
    public function getPagingStart (): int {
        return $this->pagingStart;
    }
    /**
     * Paging: length (aka number of elements)
     *
     * @return int Paging: length (aka number of elements)
     */
    public function getPagingLength (): int {
        return $this->pagingLength;
    }
}